References
==============

.. [MoosaviDiversity] `Moosavi, S. M.; Nandy, A.; Jablonka, K. M.; Ongari, D.; Janet, J. P.; Boyd, P. G.; Lee, Y.; Smit, B.; Kulik, H. J. Understanding the Diversity of the Metal-Organic Framework Ecosystem. Nature Communications 2020, 11 (1). <https://doi.org/10.1038/s41467-020-17755-8>`_

.. [BuciorMOFid] `Bucior, B. J.; Rosen, A. S.; Haranczyk, M.; Yao, Z.; Ziebel, M. E.; Farha, O. K.; Hupp, J. T.; Siepmann, J. I.; Aspuru-Guzik, A.; Snurr, R. Q. Identification Schemes for Metal–Organic Frameworks To Enable Rapid Search and Cheminformatics Analysis. Crystal Growth & Design 2019, 19 (11), 6682–6697. <https://doi.org/10.1021/acs.cgd.9b01050>`_

.. [QMUG] `Isert, C.; Atz, K.; Jiménez-Luna, J.; Schneider, G. QMugs, Quantum Mechanical Properties of Drug-like Molecules. Scientific Data 2022, 9 (1). <https://doi.org/10.1038/s41597-022-01390-7>`_

.. [Pei] `Pei, Z.; Yin, J.; Hawk, J. A.; Alman, D. E.; Gao, M. C. Machine-Learning Informed Prediction of High-Entropy Solid Solution Formation: Beyond the Hume-Rothery Rules. npj Computational Materials 2020, 6 (1). <https://doi.org/10.1038/s41524-020-0308-7>`_

.. [JablonkaAL] `Jablonka, K. M.; Jothiappan, G. M.; Wang, S.; Smit, B.; Yoo, B. Bias Free Multiobjective Active Learning for Materials Design and Discovery. Nature Communications 2021, 12 (1). <https://doi.org/10.1038/s41467-021-22437-0>`_

.. [MoosaviCp] `Moosavi, S. M.; Novotny, B. Á.; Ongari, D.; Moubarak, E.; Asgari, M.; Kadioglu, Ö.; Charalambous, C.; Ortega-Guerrero, A.; Farmahini, A. H.; Sarkisov, L.; Garcia, S.; Noé, F.; Smit, B. A Data-Science Approach to Predict the Heat Capacity of Nanoporous Materials. Nature Materials 2022, 21 (12), 1419–1425. <https://doi.org/10.1038/s41563-022-01374-3>`_

.. [NagasawaOPV] `Nagasawa,S.;Al-Naamani,E.;Saeki,A.Computer-Aided Screening of Conjugated Polymers for Organic Solar Cell: Classification by Random Forest. The Journal of Physical Chemistry Letters 2018, 9, 2639–2646. <https://pubs.acs.org/doi/10.1021/acs.jpclett.8b00635>`_

.. [ESOL] `Delaney, J. S. ESOL:  Estimating Aqueous Solubility Directly from Molecular Structure. Journal of Chemical Information and Computer Sciences 2004, 44 (3), 1000–1005. <https://doi.org/10.1021/ci034243x>`_

.. [soltest] `Mitchell, J. B. O. DLS-100 Solubility Dataset, 2017. <https://doi.org/10.17630/3A3A5ABC-8458-4924-8E6C-B804347605E8>`_ 

.. [freesolv] `Mobley, D. L.; Guthrie, J. P. FreeSolv: A Database of Experimental and Calculated Hydration Free Energies, with Input Files. Journal of Computer-Aided Molecular Design 2014, 28 (7), 711–720. <https://doi.org/10.1007/s10822-014-9747-x>`_

.. [chembl] `Gaulton, A.; Bellis, L. J.; Bento, A. P.; Chambers, J.; Davies, M.; Hersey, A.; Light, Y.; McGlinchey, S.; Michalovich, D.; Al-Lazikani, B.; Overington, J. P. ChEMBL: A Large-Scale Bioactivity Database for Drug Discovery. Nucleic Acids Research 2011, 40 (D1), D1100–D1107. <https://doi.org/10.1093/nar/gkr777>`_

.. [matbench] `Dunn, A.; Wang, Q.; Ganose, A.; Dopp, D.; Jain, A. Benchmarking Materials Property Prediction Methods: The Matbench Test Set and Automatminer Reference Algorithm. npj Computational Materials 2020, 6 (1). <https://doi.org/10.1038/s41524-020-00406-3>`_

.. [waterStability] `Batra, R.; Chen, C.; Evans, T. G.; Walton, K. S.; Ramprasad, R. Prediction of Water Stability of Metal–Organic Frameworks Using Machine Learning. Nature Machine Intelligence 2020, 2 (11), 704–710. <https://doi.org/10.1038/s42256-020-00249-z>`_

.. [Doyle] `Shields, B. J.; Stevens, J.; Li, J.; Parasram, M.; Damani, F.; Alvarado, J. I. M.; Janey, J. M.; Adams, R. P.; Doyle, A. G. Bayesian Reaction Optimization as a Tool for Chemical Synthesis. Nature 2021, 590 (7844), 89–96. <https://doi.org/10.1038/s41586-021-03213-y>`_

.. [Suzuki] `Perera, D.; Tucker, J. W.; Brahmbhatt, S.; Helal, C. J.; Chong, A.; Farrell, W.; Richardson, P.; Sach, N. W. A Platform for Automated Nanomole-Scale Reaction Screening and Micromole-Scale Synthesis in Flow. Science 2018, 359 (6374), 429–434. <https://doi.org/10.1126/science.aap9112>`_